diff --git a/application/controllers/Backend.php b/application/controllers/Backend.php
index ed314b26..4948759c 100755
--- a/application/controllers/Backend.php
+++ b/application/controllers/Backend.php
@@ -333,7 +333,7 @@ class Backend extends CI_Controller {
$view['services'] = $this->services_model->get_batch();
$view['working_plan'] = $this->settings_model->get_setting('company_working_plan');
$view['timezones'] = $this->timezones->to_array();
- $view['extra_working_plan'] = '{}';
+ $view['custom_availability_periods'] = '{}';
$this->set_user_data($view);
$this->load->view('backend/header', $view);
diff --git a/application/controllers/api/v1/Availabilities.php b/application/controllers/api/v1/Availabilities.php
index d05c2101..92714f76 100644
--- a/application/controllers/api/v1/Availabilities.php
+++ b/application/controllers/api/v1/Availabilities.php
@@ -369,13 +369,13 @@ class Availabilities extends API_V1_Controller {
/**
* Get multiple attendants hours.
*
- * This method will add the extra appointment hours whenever a service accepts multiple attendants.
+ * This method will add the additional appointment hours whenever a service accepts multiple attendants.
*
* @param string $selected_date The selected appointment date.
* @param array $service Selected service data.
* @param array $provider Selected provider data.
*
- * @return array Retunrs the available hours array.
+ * @return array Returns the available hours array.
*/
protected function _getMultipleAttendantsHours(
$selected_date,
diff --git a/application/language/arabic/translations_lang.php b/application/language/arabic/translations_lang.php
index f76f5c1f..e5368c81 100755
--- a/application/language/arabic/translations_lang.php
+++ b/application/language/arabic/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/bulgarian/translations_lang.php b/application/language/bulgarian/translations_lang.php
index babbc889..513d8006 100755
--- a/application/language/bulgarian/translations_lang.php
+++ b/application/language/bulgarian/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/catalan/translations_lang.php b/application/language/catalan/translations_lang.php
index 9aeb9a39..a8c95841 100644
--- a/application/language/catalan/translations_lang.php
+++ b/application/language/catalan/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Elimineu les vostres dades del sist
$lang['delete_personal_information'] = 'Eliminació de dades personals';
$lang['delete_personal_information_prompt'] = 'Esteu segur que voleu eliminar la vostra informació personal? Aquesta acció no es pot desfer.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/chinese/translations_lang.php b/application/language/chinese/translations_lang.php
index dff3de35..d6f71a5d 100755
--- a/application/language/chinese/translations_lang.php
+++ b/application/language/chinese/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/czech/translations_lang.php b/application/language/czech/translations_lang.php
index 3911834d..73dc2536 100644
--- a/application/language/czech/translations_lang.php
+++ b/application/language/czech/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Odstranit ze systému všechny osob
$lang['delete_personal_information'] = 'Odstranit osobní údaje';
$lang['delete_personal_information_prompt'] = 'Jste si jisti, že chcete odstranit vaše osobní údaje? Tuto akci nelze vzít zpět.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/danish/translations_lang.php b/application/language/danish/translations_lang.php
index 2ebfc138..9c6743fe 100755
--- a/application/language/danish/translations_lang.php
+++ b/application/language/danish/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Slet alle dine personlige oplysning
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/dutch/translations_lang.php b/application/language/dutch/translations_lang.php
index ca68e66f..cb7e6058 100755
--- a/application/language/dutch/translations_lang.php
+++ b/application/language/dutch/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/english/translations_lang.php b/application/language/english/translations_lang.php
index 53379cdb..845cf844 100755
--- a/application/language/english/translations_lang.php
+++ b/application/language/english/translations_lang.php
@@ -300,13 +300,13 @@ $lang['delete_personal_information_hint'] = 'Remove all your appointments and pe
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/finnish/translations_lang.php b/application/language/finnish/translations_lang.php
index 654d2b30..0891574b 100755
--- a/application/language/finnish/translations_lang.php
+++ b/application/language/finnish/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/french/translations_lang.php b/application/language/french/translations_lang.php
index 3ed8c950..76ef6a02 100755
--- a/application/language/french/translations_lang.php
+++ b/application/language/french/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Effacer toutes vos données personn
$lang['delete_personal_information'] = 'Effacer toutes mes données personnelles';
$lang['delete_personal_information_prompt'] = 'Etes-vous sûr(e) de vouloir effacer toutes vos données personnelles ? Cette action est irréversible.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/german/translations_lang.php b/application/language/german/translations_lang.php
index 3064e007..2a083d48 100755
--- a/application/language/german/translations_lang.php
+++ b/application/language/german/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Entfernen Sie alle Ihre Termine und
$lang['delete_personal_information'] = 'Persönlichen Informationen löschen';
$lang['delete_personal_information_prompt'] = 'Sind Sie sicher, dass Sie Ihre persönlichen Daten löschen möchten? Diese Aktion kann nicht rückgängig gemacht werden.';
$lang['location'] = 'Ort';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/greek/translations_lang.php b/application/language/greek/translations_lang.php
index 50068166..2e9eac4f 100755
--- a/application/language/greek/translations_lang.php
+++ b/application/language/greek/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Κατάργηση όλων των
$lang['delete_personal_information'] = 'Διαγραφή Προσωπικών Πληροφοριών';
$lang['delete_personal_information_prompt'] = 'Είστε σίγουρος ότι θέλετε να διαγράψετε τις προσωπικές σας πληροφορίες; Αυτή η ενέργεια δεν μπορεί να αναιρεθεί.';
$lang['location'] = 'Τοποθεσία';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/hindi/translations_lang.php b/application/language/hindi/translations_lang.php
index 38281034..6b0dc6b1 100755
--- a/application/language/hindi/translations_lang.php
+++ b/application/language/hindi/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/hungarian/translations_lang.php b/application/language/hungarian/translations_lang.php
index a9824b37..77a8f6c7 100755
--- a/application/language/hungarian/translations_lang.php
+++ b/application/language/hungarian/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/italian/translations_lang.php b/application/language/italian/translations_lang.php
index 21101f99..521bc27b 100755
--- a/application/language/italian/translations_lang.php
+++ b/application/language/italian/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Cancella tutti i dati personali dal
$lang['delete_personal_information'] = 'Cancella dati personali';
$lang['delete_personal_information_prompt'] = 'Sicuro di voler cancellare i tuoi dati personali? Questa operazione è irreversibile.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Giorno extra';
-$lang['extra_periods'] = 'Giorni Extra';
-$lang['extra_periods_hint'] = 'Aggiungi una giornata lavorativa al di fuori del piano di lavoro.';
-$lang['new_extra_period_title'] = 'Nuova giornata lavorativa';
-$lang['extra_period_saved'] = 'Giornata lavorativa salvata con successo!';
-$lang['add_extra_periods_during_each_day'] = 'Aggiungi giornate lavorative al di fuori del piano di lavoro.';
-$lang['add_extra_period'] = 'Aggiungi giornata lavorativa';
+$lang['custom_availability_period'] = 'Giorno extra';
+$lang['custom_availability_periods'] = 'Giorni Extra';
+$lang['custom_availability_periods_hint'] = 'Aggiungi una giornata lavorativa al di fuori del piano di lavoro.';
+$lang['new_custom_availability_period_title'] = 'Nuova giornata lavorativa';
+$lang['custom_availability_period_saved'] = 'Giornata lavorativa salvata con successo!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Aggiungi giornate lavorative al di fuori del piano di lavoro.';
+$lang['add_custom_availability_period'] = 'Aggiungi giornata lavorativa';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/japanese/translations_lang.php b/application/language/japanese/translations_lang.php
index b51e512f..6ea00436 100755
--- a/application/language/japanese/translations_lang.php
+++ b/application/language/japanese/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/luxembourgish/translations_lang.php b/application/language/luxembourgish/translations_lang.php
index 5b2b9651..15546526 100755
--- a/application/language/luxembourgish/translations_lang.php
+++ b/application/language/luxembourgish/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/marathi/translations_lang.php b/application/language/marathi/translations_lang.php
index 3057516c..c38a4e6a 100644
--- a/application/language/marathi/translations_lang.php
+++ b/application/language/marathi/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'सिस्टमवरून स
$lang['delete_personal_information'] = 'वैयक्तिक माहिती हटवा';
$lang['delete_personal_information_prompt'] = 'आपली खात्री आहे की आपण आपली वैयक्तिक माहिती हटवू इच्छिता? ही क्रिया पूर्ववत करणे शक्य नाही.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/polish/translations_lang.php b/application/language/polish/translations_lang.php
index ca41c520..cb8531ca 100755
--- a/application/language/polish/translations_lang.php
+++ b/application/language/polish/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/portuguese-br/translations_lang.php b/application/language/portuguese-br/translations_lang.php
index cd2687f7..5a8ebcec 100755
--- a/application/language/portuguese-br/translations_lang.php
+++ b/application/language/portuguese-br/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Deletar toda informação pessoal d
$lang['delete_personal_information'] = 'Deletar Informação Pessoal';
$lang['delete_personal_information_prompt'] = 'Tem certeza que deja deletar suas informações pessoais? Essa ação não pode ser desfeita.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/portuguese/translations_lang.php b/application/language/portuguese/translations_lang.php
index bd51b198..5b48ac64 100755
--- a/application/language/portuguese/translations_lang.php
+++ b/application/language/portuguese/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/romanian/translations_lang.php b/application/language/romanian/translations_lang.php
index e00ee293..992d49d0 100755
--- a/application/language/romanian/translations_lang.php
+++ b/application/language/romanian/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/russian/translations_lang.php b/application/language/russian/translations_lang.php
index 1886a8c1..7877df3f 100755
--- a/application/language/russian/translations_lang.php
+++ b/application/language/russian/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/slovak/translations_lang.php b/application/language/slovak/translations_lang.php
index 04ec9f79..babc0ee0 100755
--- a/application/language/slovak/translations_lang.php
+++ b/application/language/slovak/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/spanish/translations_lang.php b/application/language/spanish/translations_lang.php
index fe6388ca..89ebfc5d 100755
--- a/application/language/spanish/translations_lang.php
+++ b/application/language/spanish/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Borrar toda la información persona
$lang['delete_personal_information'] = 'Borrar información personal';
$lang['delete_personal_information_prompt'] = '¿Estás seguro que quieres borrar tu información personal? Esta acción no se puede deshacer.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/language/swedish/translations_lang.php b/application/language/swedish/translations_lang.php
index 18c0090a..b2bdccf4 100755
--- a/application/language/swedish/translations_lang.php
+++ b/application/language/swedish/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Ta bort all dina personliga uppgift
$lang['delete_personal_information'] = 'Ta bort Personlig Information';
$lang['delete_personal_information_prompt'] = 'Är du säker på att du vill ta bort all information om dig från systemet? Det går inte att återställa informationen om du ångrar dig.';
$lang['location'] = 'Plats';
-$lang['extra_period'] = 'Extra arbetsdag';
-$lang['extra_periods'] = 'Extra arbetsdagar';
-$lang['extra_periods_hint'] = 'Lägg till en arbetsdag utanför schemat.';
-$lang['new_extra_period_title'] = 'Ny arbetsdag';
-$lang['extra_period_saved'] = 'Den nya arbetsdagen är sparad.';
-$lang['add_extra_periods_during_each_day'] = 'Lägg till arbetsdagar utanför schemat.';
-$lang['add_extra_period'] = 'Lägg till en arbetsdag.';
+$lang['custom_availability_period'] = 'Extra arbetsdag';
+$lang['custom_availability_periods'] = 'Extra arbetsdagar';
+$lang['custom_availability_periods_hint'] = 'Lägg till en arbetsdag utanför schemat.';
+$lang['new_custom_availability_period_title'] = 'Ny arbetsdag';
+$lang['custom_availability_period_saved'] = 'Den nya arbetsdagen är sparad.';
+$lang['add_custom_availability_periods_during_each_day'] = 'Lägg till arbetsdagar utanför schemat.';
+$lang['add_custom_availability_period'] = 'Lägg till en arbetsdag.';
$lang['require_phone_number'] = 'Kräv telefonnummer.';
$lang['require_phone_number_hint'] = 'När denna är aktiv måste kunderna ange ett telefonnummer för att kunna göra en bokning.';
$lang['check_spam_folder'] = 'Om eposten inte kommit fram inom några minuter; kolla skräpposten.';
diff --git a/application/language/turkish/translations_lang.php b/application/language/turkish/translations_lang.php
index 6c306bf5..e1d24a6f 100755
--- a/application/language/turkish/translations_lang.php
+++ b/application/language/turkish/translations_lang.php
@@ -298,13 +298,13 @@ $lang['delete_personal_information_hint'] = 'Delete all personal information fro
$lang['delete_personal_information'] = 'Delete Personal Information';
$lang['delete_personal_information_prompt'] = 'Are you sure that you want to delete your personal information? This action cannot be undone.';
$lang['location'] = 'Location';
-$lang['extra_period'] = 'Extra working day';
-$lang['extra_periods'] = 'Extra working days';
-$lang['extra_periods_hint'] = 'Add a working day outside the working plan.';
-$lang['new_extra_period_title'] = 'New working day';
-$lang['extra_period_saved'] = 'New working day saved successfully!';
-$lang['add_extra_periods_during_each_day'] = 'Add working days outside the working plan.';
-$lang['add_extra_period'] = 'Add a working day';
+$lang['custom_availability_period'] = 'Custom availability period';
+$lang['custom_availability_periods'] = 'Custom availability periods';
+$lang['custom_availability_periods_hint'] = 'Add a working day outside the working plan.';
+$lang['new_custom_availability_period_title'] = 'New working day';
+$lang['custom_availability_period_saved'] = 'New working day saved successfully!';
+$lang['add_custom_availability_periods_during_each_day'] = 'Add working days outside the working plan.';
+$lang['add_custom_availability_period'] = 'Add a working day';
$lang['require_phone_number'] = 'Require phone number';
$lang['require_phone_number_hint'] = 'When enabled, customers and users will need to enter the customer\'s phone number when booking an appointment';
$lang['check_spam_folder'] = 'Please check your spam folder if the email does not arrive within a few minutes.';
diff --git a/application/migrations/015_add_extra_working_plan_to_user_settings.php b/application/migrations/015_add_extra_working_plan_to_user_settings.php
index 90522bd7..7ae20c96 100644
--- a/application/migrations/015_add_extra_working_plan_to_user_settings.php
+++ b/application/migrations/015_add_extra_working_plan_to_user_settings.php
@@ -12,21 +12,21 @@
* ---------------------------------------------------------------------------- */
/**
- * Class Migration_Add_extra_working_plan_to_user_settings
+ * Class Migration_Add_custom_availability_periods_to_user_settings
*
* @property CI_DB_query_builder db
* @property CI_DB_forge dbforge
*/
-class Migration_Add_extra_working_plan_to_user_settings extends CI_Migration {
+class Migration_Add_custom_availability_periods_to_user_settings extends CI_Migration {
/**
* Upgrade method.
*/
public function up()
{
- if ( ! $this->db->field_exists('extra_working_plan', 'user_settings'))
+ if ( ! $this->db->field_exists('custom_availability_periods', 'user_settings'))
{
$fields = [
- 'extra_working_plan' => [
+ 'custom_availability_periods' => [
'type' => 'TEXT',
'null' => TRUE,
'after' => 'working_plan'
@@ -42,9 +42,9 @@ class Migration_Add_extra_working_plan_to_user_settings extends CI_Migration {
*/
public function down()
{
- if ( ! $this->db->field_exists('extra_working_plan', 'user_settings'))
+ if ( ! $this->db->field_exists('custom_availability_periods', 'user_settings'))
{
- $this->dbforge->drop_column('user_settings', 'extra_working_plan');
+ $this->dbforge->drop_column('user_settings', 'custom_availability_periods');
}
}
}
diff --git a/application/views/backend/calendar.php b/application/views/backend/calendar.php
index 7c27ba7c..32f7ec68 100755
--- a/application/views/backend/calendar.php
+++ b/application/views/backend/calendar.php
@@ -9,7 +9,7 @@
-
+
diff --git a/application/controllers/Appointments.php b/application/controllers/Appointments.php
index 779d00bf..3df90e80 100755
--- a/application/controllers/Appointments.php
+++ b/application/controllers/Appointments.php
@@ -519,8 +519,8 @@ class Appointments extends CI_Controller {
// Get the service, provider's working plan and provider appointments.
$working_plan = json_decode($this->providers_model->get_setting('working_plan', $provider_id), TRUE);
- // Get the provider's extra working plan.
- $extra_working_plan = json_decode($this->providers_model->get_setting('extra_working_plan', $provider_id), TRUE);
+ // Get the provider's custom availability periods.
+ $custom_availability_periods = json_decode($this->providers_model->get_setting('custom_availability_periods', $provider_id), TRUE);
$provider_appointments = $this->appointments_model->get_batch([
'id_users_provider' => $provider_id,
@@ -543,12 +543,12 @@ class Appointments extends CI_Controller {
// every reserved appointment is considered to be a taken space in the plan.
$selected_date_working_plan = $working_plan[strtolower(date('l', strtotime($selected_date)))];
// Search if the $selected_date is an extra date added outside the normal working plan
if ($selected_date_working_plan == NULL)
{
- if (isset($extra_working_plan[strtolower(date('Y-m-d', strtotime($selected_date)))]))
+ if (isset($custom_availability_periods[strtolower(date('Y-m-d', strtotime($selected_date)))]))
{
- $selected_date_working_plan = $extra_working_plan[strtolower(date('Y-m-d', strtotime($selected_date)))];
+ $selected_date_working_plan = $custom_availability_periods[strtolower(date('Y-m-d', strtotime($selected_date)))];
}
}
@@ -757,7 +757,7 @@ class Appointments extends CI_Controller {
/**
* Get multiple attendants hours.
*
- * This method will add the extra appointment hours whenever a service accepts multiple attendants.
+ * This method will add the additional appointment hours whenever a service accepts multiple attendants.
*
* @param string $selected_date The selected appointment date.
* @param array $service Selected service data.
@@ -543,12 +543,12 @@ class Appointments extends CI_Controller {
// every reserved appointment is considered to be a taken space in the plan.
$selected_date_working_plan = $working_plan[strtolower(date('l', strtotime($selected_date)))];
- // Search if the $selected_date is an extra date added outside the normal working plan
+ // Search if the $selected_date is an custom availability period added outside the normal working plan.
if ($selected_date_working_plan == NULL)
{
diff --git a/application/controllers/Backend_api.php b/application/controllers/Backend_api.php
index 89f6e43d..e710f553 100755
--- a/application/controllers/Backend_api.php
+++ b/application/controllers/Backend_api.php
@@ -857,16 +857,16 @@ class Backend_api extends CI_Controller {
}
/**
- * Insert of update extra working plan time period to database.
+ * Insert of update custom availability periods to database.
*/
- public function ajax_save_extra_period()
+ public function ajax_save_custom_availability_period()
{
try
{
// Check privileges
- $extra_period = json_decode($this->input->post('extra_period'), TRUE);
+ $custom_availability_period = json_decode($this->input->post('custom_availability_period'), TRUE);
- $required_privileges = ( ! isset($extra_period['id']))
+ $required_privileges = ( ! isset($custom_availability_period['id']))
? $this->privileges[PRIV_APPOINTMENTS]['add']
: $this->privileges[PRIV_APPOINTMENTS]['edit'];
if ($required_privileges == FALSE)
@@ -876,7 +876,7 @@ class Backend_api extends CI_Controller {
$this->load->model('providers_model');
- $success = $this->providers_model->set_extra_working_day($extra_period, $extra_period['id_users_provider']);
+ $success = $this->providers_model->set_custom_availability_period($custom_availability_period, $custom_availability_period['id_users_provider']);
if ($success)
{
@@ -884,7 +884,7 @@ class Backend_api extends CI_Controller {
}
else
{
- $response = ['warnings' => 'Error on saving extra period.'];
+ $response = ['warnings' => 'Error on saving custom availability period.'];
}
}
catch (Exception $exception)
@@ -903,9 +903,9 @@ class Backend_api extends CI_Controller {
}
/**
* Delete an extra working plan time period to database.
*/
- public function ajax_delete_extra_period()
+ public function ajax_delete_custom_availability_period()
{
try
{
@@ -915,13 +915,13 @@ class Backend_api extends CI_Controller {
}
// Check privileges
- $extra_period = $this->input->post('extra_period');
+ $custom_availability_period = $this->input->post('custom_availability_period');
$provider_id = $this->input->post('provider_id');
$this->load->model('providers_model');
// Delete unavailable
- $success = $this->providers_model->delete_extra_working_day($extra_period, $provider_id);
+ $success = $this->providers_model->delete_custom_availability_period($custom_availability_period, $provider_id);
if ($success)
{
@@ -929,7 +929,7 @@ class Backend_api extends CI_Controller {
}
else
{
- $response = ['warnings' => 'Error on deleting extra period.'];
+ $response = ['warnings' => 'Error on deleting custom availability period.'];
}
}
catch (Exception $exception)
@@ -903,9 +903,9 @@ class Backend_api extends CI_Controller {
}
/**
- * Delete an extra working plan time period to database.
+ * Delete an custom availability periods time period to database.
*/
diff --git a/application/models/Providers_model.php b/application/models/Providers_model.php
index 394da1a8..141bba4f 100755
--- a/application/models/Providers_model.php
+++ b/application/models/Providers_model.php
@@ -322,8 +322,8 @@ class Providers_Model extends CI_Model {
foreach ($settings as $name => $value)
{
- // Sort in descending order the extra working plan days
- if ($name == 'extra_working_plan')
+ // Sort in descending order the custom availability periods
+ if ($name == 'custom_availability_periods')
{
$value = json_decode($value, TRUE);
// Sort the array and put in reverse order
@@ -634,22 +634,22 @@ class Providers_Model extends CI_Model {
}
/**
- * Save the provider extra working plan days.
+ * Save the provider custom availability period.
*
* @param array $extra_period Contains the date and the hours of the extra working plan day.
* @param int $provider_id The selected provider record id.
*
* @return bool Return if the new extra working plan is correctly saved to DB.
*
* @throws Exception If start time is after the end time.
* @throws Exception If $provider_id argument is invalid.
*/
- public function set_extra_working_day($extra_period, $provider_id)
+ public function set_custom_availability_period($custom_availability_period, $provider_id)
{
// Validate period
- $dateStart = date('Y-m-d', strtotime($extra_period['start_datetime']));
- $start = date('H:i', strtotime($extra_period['start_datetime']));
- $end = date('H:i', strtotime($extra_period['end_datetime']));
+ $dateStart = date('Y-m-d', strtotime($custom_availability_period['start_datetime']));
+ $start = date('H:i', strtotime($custom_availability_period['start_datetime']));
+ $end = date('H:i', strtotime($custom_availability_period['end_datetime']));
if ($start > $end)
{
throw new Exception('Unavailable period start must be prior to end.');
@@ -667,17 +667,15 @@ class Providers_Model extends CI_Model {
}
// Add record to database.
- $extra_working_plan = json_decode($this->get_setting('extra_working_plan', $provider_id), TRUE);
+ $custom_availability_periods = json_decode($this->get_setting('custom_availability_periods', $provider_id), TRUE);
- $extra_working_plan[$dateStart] = [
+ $custom_availability_periods[$dateStart] = [
'start' => $start,
'end' => $end,
'breaks' => []
];
- $success = $this->set_setting('extra_working_plan', json_encode($extra_working_plan), $provider_id);
-
- return $success;
+ return $this->set_setting('custom_availability_periods', json_encode($custom_availability_periods), $provider_id);
}
/**
@@ -695,16 +693,16 @@ class Providers_Model extends CI_Model {
}
/**
- * Delete a provider extra working plan day.
+ * Delete a provider custom availability period.
*
* @param string $extra_period Contains the date to be deleted from the extra working plan.
* @param int $provider_id The selected provider record id.
*
* @return bool Return if the new extra working plan is correctly deleted from DB.
*
* @throws Exception If $provider_id argument is invalid.
*/
- public function delete_extra_working_day($extra_period, $provider_id)
+ public function delete_custom_availability_period($custom_availability_period, $provider_id)
{
// Validate provider record
$where_clause = [
@@ -718,12 +716,10 @@ class Providers_Model extends CI_Model {
}
// Add record to database.
- $extra_working_plan = json_decode($this->get_setting('extra_working_plan', $provider_id), TRUE);
+ $custom_availability_periods = json_decode($this->get_setting('custom_availability_periods', $provider_id), TRUE);
- unset($extra_working_plan[$extra_period]);
+ unset($custom_availability_periods[$custom_availability_period]);
- $success = $this->set_setting('extra_working_plan', json_encode($extra_working_plan), $provider_id);
-
- return $success;
+ return $this->set_setting('custom_availability_periods', json_encode($custom_availability_periods), $provider_id);
}
}
@@ -634,22 +634,22 @@ class Providers_Model extends CI_Model {
*
- * @param array $extra_period Contains the date and the hours of the extra working plan day.
+ * @param array $custom_availability_period Contains the date and the hours of the Custom availability period.
* @param int $provider_id The selected provider record id.
*
@@ -634,22 +634,22 @@ class Providers_Model extends CI_Model {
* @param int $provider_id The selected provider record id.
*
- * @return bool Return if the new extra working plan is correctly saved to DB.
+ * @return bool Return if the new custom availability periods is correctly saved to DB.
*
* @throws Exception If start time is after the end time.
@@ -695,16 +693,16 @@ class Providers_Model extends CI_Model {
*
- * @param string $extra_period Contains the date to be deleted from the extra working plan.
+ * @param string $custom_availability_period Contains the date to be deleted from the custom availability periods.
* @param int $provider_id The selected provider record id.
*
@@ -695,16 +693,16 @@ class Providers_Model extends CI_Model {
* @param int $provider_id The selected provider record id.
*
- * @return bool Return if the new extra working plan is correctly deleted from DB.
+ * @return bool Return if the new custom availability periods is correctly deleted from DB.
*
* @throws Exception If $provider_id argument is invalid.